@@ -46,7 +46,7 @@ download_volume_zip <- function(vol_id = 31,
     }
     rq <- databraryr::make_default_request()
   }
-  rq <- rq |>
+  rq <- rq %>%
     httr2::req_url(sprintf(GET_VOLUME_ZIP, vol_id))
   
   resp <- tryCatch(
