@@ -13,6 +13,10 @@ test_that("list_volume_funding rejects bad input parameters", {
   expect_error(list_volume_funding(vb = 3))
   expect_error(list_volume_funding(vb = "a"))
   expect_error(list_volume_funding(vb = list(a=1, b=2)))
+  
+  expect_error(list_volume_funding(rq = "a"))
+  expect_error(list_volume_funding(rq = -1))
+  expect_error(list_volume_funding(rq = c(2,3)))
+  expect_error(list_volume_funding(rq = list(a=1, b=2)))
+  
 })
-
-#
\ No newline at end of file
